==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/DockManagerPoint.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var DockManagerPoint = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManagerPoint, _super);
    function DockManagerPoint() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(DockManagerPoint.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerPoint.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.a.n = this.e;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerPoint.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManagerPoint.prototype, "c", {
        get: function () {
            var ret_ = this.b.m("x");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("x", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerPoint.prototype, "d", {
        get: function () {
            var ret_ = this.b.m("y");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.u("y", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockManagerPoint.$t = markType(DockManagerPoint, 'DockManagerPoint');
    return DockManagerPoint;
}(Base));
export { DockManagerPoint };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/DockManagerPoint.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var DockManagerPoint = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManagerPoint, _super);
    function DockManagerPoint() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(DockManagerPoint.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerPoint.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.a.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerPoint.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManagerPoint.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("x");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("x", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerPoint.prototype, "d", {
        get: function () {
            var ret_ = this.b.n("y");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("y", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockManagerPoint.$t = markType(DockManagerPoint, 'DockManagerPoint');
    return DockManagerPoint;
}(Base));
export { DockManagerPoint };
